Rocco Rutte:
[apps/madmutt.git] / account.c
index a857829..aff9d3a 100644 (file)
--- a/account.c
+++ b/account.c
@@ -1,19 +1,10 @@
 /*
- * Copyright (C) 2000-3 Brendan Cully <brendan@kublai.com>
- * 
- *     This program is free software; you can redistribute it and/or modify
- *     it under the terms of the GNU General Public License as published by
- *     the Free Software Foundation; either version 2 of the License, or
- *     (at your option) any later version.
- * 
- *     This program is distributed in the hope that it will be useful,
- *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- * 
- *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Copyright notice from original mutt:
+ * Copyright (C) 2000-5 Brendan Cully <brendan@kublai.com>
+ *
+ * This file is part of mutt-ng, see http://www.muttng.org/.
+ * It's licensed under the GNU General Public License,
+ * please see the file GPL in the top level source directory.
  */
 
 /* remote host account manipulation (POP/IMAP) */
 #include "account.h"
 #include "url.h"
 
-/* mutt_account_match: compare account info (host/port/user) */
+#include "lib/mem.h"
+#include "lib/intl.h"
+#include "lib/str.h"
+
+/* mutt_account_match: compare account info (host/port/user/login) */
 int mutt_account_match (const ACCOUNT * a1, const ACCOUNT * a2)
 {
-  const char *user = NONULL (Username);
+  const char* user = NONULL (Username);
+  const char* login = NONULL (Username);
 
   if (a1->type != a2->type)
     return 0;
@@ -39,8 +35,12 @@ int mutt_account_match (const ACCOUNT * a1, const ACCOUNT * a2)
     return 0;
 
 #ifdef USE_IMAP
-  if (a1->type == M_ACCT_TYPE_IMAP && ImapUser)
-    user = ImapUser;
+  if (a1->type == M_ACCT_TYPE_IMAP) {
+    if (ImapUser)
+      user = ImapUser;
+    if (ImapLogin)
+      login = ImapLogin;
+  }
 #endif
 
 #ifdef USE_POP
@@ -54,11 +54,11 @@ int mutt_account_match (const ACCOUNT * a1, const ACCOUNT * a2)
 #endif
 
   if (a1->flags & a2->flags & M_ACCT_USER)
-    return (!strcmp (a1->user, a2->user));
+    return (!mutt_strcmp (a1->user, a2->user));
   if (a1->flags & M_ACCT_USER)
-    return (!strcmp (a1->user, user));
+    return (!mutt_strcmp (a1->user, user));
   if (a2->flags & M_ACCT_USER)
-    return (!strcmp (a2->user, user));
+    return (!mutt_strcmp (a2->user, user));
 
   return 1;
 }
@@ -135,7 +135,7 @@ void mutt_account_tourl (ACCOUNT * account, ciss_url_t * url)
     url->pass = account->pass;
 }
 
-/* mutt_account_getuser: retrieve username into ACCOUNT, if neccessary */
+/* mutt_account_getuser: retrieve username into ACCOUNT, if necessary */
 int mutt_account_getuser (ACCOUNT * account)
 {
   char prompt[SHORT_STRING];
@@ -168,6 +168,28 @@ int mutt_account_getuser (ACCOUNT * account)
   return 0;
 }
 
+int mutt_account_getlogin (ACCOUNT* account)
+{
+  /* already set */
+  if (account->flags & M_ACCT_LOGIN)
+    return 0;
+#ifdef USE_IMAP
+  else if (account->type == M_ACCT_TYPE_IMAP)
+  {
+    if (ImapLogin)
+      strfcpy (account->login, ImapLogin, sizeof (account->login));
+    else {
+      mutt_account_getuser (account);
+      strfcpy (account->login, account->user, sizeof (account->login));
+    }
+  }
+#endif
+
+  account->flags |= M_ACCT_LOGIN;
+
+  return 0;
+}
+
 /* mutt_account_getpass: fetch password into ACCOUNT, if neccessary */
 int mutt_account_getpass (ACCOUNT * account)
 {
@@ -189,7 +211,7 @@ int mutt_account_getpass (ACCOUNT * account)
 #endif
   else {
     snprintf (prompt, sizeof (prompt), _("Password for %s@%s: "),
-              account->user, account->host);
+              account->login, account->host);
     account->pass[0] = '\0';
     if (mutt_get_password (prompt, account->pass, sizeof (account->pass)))
       return -1;